@@ -1,7 +1,6 @@
 import time
 
 import requests
-import json
 
 import backoff
 
@@ -66,18 +65,15 @@ class GraphQLClient:
 
         if variables is None:
             headers['Content-Type'] = 'application/json'
-            payload = json.dumps({'query': query}).encode('utf-8')
         elif variables.get('file', None) is not None:
             headers['content'] = 'multipart/form-data'
             files = [
                 ('variables[file]', (variables['file'], open(variables['file'], 'rb')))
             ]
 
-        try:
-            response = requests.request("POST", self.endpoint, headers=headers, data=payload, files=files)
-            response.raise_for_status()
-            return response.json()
-        except requests.HTTPError as e:
-            print(e)
+        response = requests.post(url=self.endpoint, headers=headers, json=payload, files=files)
+        if not response.ok:
             print(f"Original payload: {payload}")
-            raise e
+            print(response.text)
+            response.raise_for_status()
+        return response.json()
