@@ -757,14 +757,14 @@ def get_board_activity_query(board_id, from_date, to_date, page, limit):
 
 def create_webhook_query(board_id, url, event, column_id: Optional[str]):
     column_config = f', config: "{{\\"columnId\\": \\"{column_id}\\"}}"' if column_id else ''
-    query = '''
-    mutation {
-        create_webhook (board_id:%s, url: \"%s\", event: %s%s) {
+    query = rf"""
+    mutation {{
+        create_webhook (board_id:{board_id}, url: "{url}", event: {event}{column_config}) {{
             id
             board_id
-        }
-    }
-    ''' % (board_id, url, event, column_config)
+        }}
+    }}
+    """
     return query
 
 
